package xmlrpc;

import java.net.InetAddress;

import org.apache.xmlrpc.server.PropertyHandlerMapping;
import org.apache.xmlrpc.server.XmlRpcServer;
import org.apache.xmlrpc.server.XmlRpcServerConfigImpl;
import org.apache.xmlrpc.webserver.WebServer;

public class Server {
    private static final int port = 8080;

    public static void main(String[] args) throws Exception {
        // spust web server 
    	InetAddress addr = InetAddress.getLocalHost();
        WebServer webServer = new WebServer(port, addr); //neoptimalni - lepsi je pouzit servlet !!!
        System.out.println("Server started on "+addr+" on port "+port);
        // ziskej XML-RPC Server
        XmlRpcServer xmlRpcServer = webServer.getXmlRpcServer();
      
        /* Definice handleru muhou byt nacteny ze souboru (property file)
         * Obecne jde o prirazeni jmena (jakykoliv string) FQN implementujici tride.
         * 'property file' by mohlo vypadat nasledovne:
         *   CalculatorImpl=org.apache.xmlrpc.demo.Calculator
         *   org.apache.xmlrpc.demo.proxy.Adder=org.apache.xmlrpc.demo.proxy.AdderImpl
         *
         * phm.load(Thread.currentThread().getContextClassLoader(),
         *        "MyHandlers.properties");
         *
         * Dalsi moznosti je prima definice. Napr.:
         * phm.addHandler("CalculatorImpl",
         *     org.apache.xmlrpc.demo.Calculator.class);
         * phm.addHandler(org.apache.xmlrpc.demo.proxy.Adder.class.getName(),
         *     org.apache.xmlrpc.demo.proxy.AdderImpl.class);
         */
        PropertyHandlerMapping phm = new PropertyHandlerMapping();
        phm.addHandler("xmlrpc.Calculator", CalculatorImpl.class);
        // prirad mapovani
        xmlRpcServer.setHandlerMapping(phm);
        // nastav konfiguraci
        XmlRpcServerConfigImpl serverConfig =
            (XmlRpcServerConfigImpl) xmlRpcServer.getConfig();
        serverConfig.setEnabledForExtensions(false);
        serverConfig.setContentLengthOptional(false);
        // spust server
        webServer.start();
    }
}

